## 0.1.1 (2025-01-23)

### Fix

- convert to vec intermediate rep to resolve to_pyarray not found error
- breaking ordering semantics of sample

## 0.1.0 (2025-01-23)

### Feat

- build base distribution types
- migrate sumtree from replaytables

### Fix

- checkout code in order to tag
- automate tagging and publishing

### Refactor

- migrate from multi-dim sumtree -> single-dim
